
# Type: singular_name


a name that is used in the singular form

URI: [meta:singular_name](https://w3id.org/biolink/biolinkml/meta/singular_name)


## Domain and Range

[SlotDefinition](SlotDefinition.md) ->  <sub>OPT</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * [SlotDefinition](SlotDefinition.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | skos:altLabel |

